- 查看帮助文档

    `python p2r.py -h`

- 参数注解 -f PostManScript脚本文件
    
    `python p2r.py -f postmanScript.json`

- 参数注解 -p pyScript脚本文件 *默认脚本名为api_test_script.py

    `python p2r.py -f postmanScript.json -p test_api.py`